_me = obj_tag_color.prototype;
function obj_tag_color(){};

/**
 * @brief: CONSTRUCTOR
 * @date : 29.1.2013
 **/
_me.__constructor = async function(){
	this._listen_data('tags');	
};

_me._listen_data = function(sDataSet,aDataPath){
	this._listener_data = sDataSet;
	if (typeof aDataPath == 'object') this._listenerPath_data = aDataPath;
	dataSet.obey(this,'_listener_data',sDataSet);
};

_me.__update = function(sDataSet){

	if (!sDataSet || this._destructed) return;

	// update tag colors
	if (this._listener_data == sDataSet)
		this._value(this._value());
	// update value
	else
	if (this._listener == sDataSet)
		this._value(dataSet.get(this._listener,this._listenerPath));
};

_me._decode = function(v){

	var aTags = dataSet.get(this._listener_data, this._listenerPath_data) || {},
		aIN = v.split(','),
		aOut = [];

	var NM = NightMode();
	var invertStyleProperty = NM.invertStyleProperty.bind(NM);

	for (var i in aIN)
		if ((aIN[i] = aIN[i].trim())){
			var tagColor = (aTags[aIN[i]] || {}).TAGCOLOR;
			var textColor = (aTags[aIN[i]] || {}).TEXTCOLOR || '#000000';
			var id;
			if (dataSet.get('main', ['night_mode_enabled'])) {
				var inverted = invertStyleProperty('color', textColor);
				id = inverted.id;
				textColor = inverted.color;
				inverted = tagColor ? invertStyleProperty('background-color', tagColor, id) : { id: id };
				id = inverted.id;
				tagColor = tagColor ? inverted.color : '';
			}
			aOut.push({
				tag:aIN[i],
				id: id,
				ID: (aTags[aIN[i]] || {}).ID,
				bgcolor: (aTags[aIN[i]] && tagColor || ''),
				color: (aTags[aIN[i]] && textColor || '')
			});
		}	

	return aOut;
};